@@ -4,7 +4,7 @@
 *
 * psinfo: process info
 *
-* Copyright (C) 2008 Ward van Wanrooij <ward@ward.nu>
+* Copyright (C) 2008-2010 Ward van Wanrooij <ward@ward.nu>
 *
 * This software may be distributed according to the terms of the GNU
 * General Public License, version 2 or (at your option) any later
@@ -237,8 +237,8 @@ int parse_proc_task(char *name, int **s) {
 		int sz;
 
 		sz = 0;
-		*s = realloc(*s, cnt);
-		memset(*s, 0, cnt);
+		*s = realloc(*s, sizeof(int) * cnt);
+		memset(*s, 0, sizeof(int) * cnt);
 		while (cnt--) {
 			if (files[cnt]->d_name[0] != '.') {
 				int tpid;
@@ -653,8 +653,8 @@ int parse_proc(char *base, int pid, struct process_info *p)
 
 void print_help()
 {
-	printf("psinfo 0.1\n");
-	printf("Copyright (C) 2008 Ward van Wanrooij <ward@ward.nu>\n");
+	printf("psinfo 0.12\n");
+	printf("Copyright (C) 2008-2010 Ward van Wanrooij <ward@ward.nu>\n");
 	printf("This software may be distributed according to the terms of the GNU\n");
 	printf("General Public License, version 2 or (at your option) any later version.\n");
 	printf("\n");
@@ -734,6 +734,7 @@ int main(int argc, char **argv)
 		output_signal = 1;
 	}
 	if ((p = malloc(sizeof(struct process_info))) != NULL) {
+		tzset();
 		memset(p, 0, sizeof(struct process_info));
 		if (!(result = (parse_proc("/proc", pid, p)))) {
 			if (output_general)
